@@ -308,7 +308,7 @@ class Corpus(object):
         self.n_docs += 1
         self.n_tokens += len(doc)
         if doc.is_sentenced:
-            self.n_sents += sum(1 for _ in doc.sents)
+            self.n_sents += itertoolz.count(doc.sents)
 
     # get documents
 
@@ -333,9 +333,6 @@ class Corpus(object):
         Yields:
             :class:`spacy.tokens.Doc`: Next document passing ``match_func``.
 
-        See Also:
-            :meth:`Corpus.remove()`
-
         .. tip:: To get doc(s) by index, treat :class:`Corpus` as a list and use
            Python's usual indexing and slicing: ``Corpus[0]`` gets the first
            document in the corpus; ``Corpus[:5]`` gets the first 5; etc.
@@ -365,9 +362,6 @@ class Corpus(object):
                 removes docs whose author was given as "Burton DeWilde".
             limit (int): Maximum number of matched docs to remove.
 
-        See Also:
-            :meth:`Corpus.get()`
-
         .. tip:: To remove doc(s) by index, treat :class:`Corpus` as a list and use
            Python's usual indexing and slicing: ``del Corpus[0]`` removes the
            first document in the corpus; ``del Corpus[:5]`` removes the first
@@ -388,7 +382,7 @@ class Corpus(object):
         self.n_docs -= 1
         self.n_tokens -= len(doc)
         if doc.is_sentenced:
-            self.n_sents -= sum(1 for _ in doc.sents)
+            self.n_sents -= itertoolz.count(doc.sents)
         del self.docs[idx]
         del self._doc_ids[idx]
 
@@ -409,8 +403,9 @@ class Corpus(object):
     def word_counts(self, normalize="lemma", weighting="count", as_strings=False):
         """
         Map the set of unique words in :class:`Corpus` to their counts as
-        absolute, relative, or binary frequencies of occurence,
-        similar to :meth:`Doc._.to_bag_of_words()` but aggregated over all docs.
+        absolute, relative, or binary frequencies of occurence, similar to
+        :meth:`Doc._.to_bag_of_words() <textacy.spacier.doc_extensions.to_bag_of_words>`
+        but aggregated over all docs.
 
         Args:
             normalize (str): If "lemma", lemmatize words before counting; if
@@ -435,7 +430,7 @@ class Corpus(object):
             of occurrence (depending on the value of ``weighting``).
 
         See Also:
-            :func:`textacy.vsm.get_term_freqs()`
+            * :func:`textacy.vsm.get_term_freqs() <textacy.vsm.matrix_utils.get_term_freqs>`
         """
         word_counts_ = collections.Counter()
         for doc in self:
@@ -490,7 +485,7 @@ class Corpus(object):
             on the value of ``weighting``).
 
         See Also:
-            :func:`textacy.vsm.get_doc_freqs()`
+            * :func:`textacy.vsm.get_doc_freqs() <textacy.vsm.matrix_utils.get_doc_freqs>`
         """
         word_doc_counts_ = collections.Counter()
         for doc in self:
