@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
-spaCy Doc extensions
---------------------
+Doc extensions
+--------------
 
 Functionality for inspecting, customizing, and transforming spaCy's core
 data structure, :class:`spacy.tokens.Doc`, accessible directly as functions
@@ -19,12 +19,15 @@ on instantiated docs prepended by an underscore:
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+import types
+
 import spacy
 from cytoolz import itertoolz
 
 from .. import constants
 from .. import extract
 from .. import network
+from .. import utils
 
 __all__ = [
     "set_doc_extensions",
@@ -75,9 +78,12 @@ def remove_doc_extensions():
 
 def get_lang(doc):
     """
-    Get the standard, two-letter language code assigned to ``doc``
+    Get the standard, two-letter language code assigned to ``Doc``
     and its associated :class:`spacy.vocab.Vocab`.
 
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
+
     Returns:
         str
     """
@@ -86,9 +92,12 @@ def get_lang(doc):
 
 def get_preview(doc):
     """
-    Get a short preview of the ``doc``, including the number of tokens
+    Get a short preview of the ``Doc``, including the number of tokens
     and an initial snippet.
 
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
+
     Returns:
         str
     """
@@ -100,7 +109,10 @@ def get_preview(doc):
 
 def get_tokens(doc):
     """
-    Yield the tokens in ``doc``, one at a time.
+    Yield the tokens in ``Doc``, one at a time.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
 
     Yields:
         :class:`spacy.tokens.Token`
@@ -111,7 +123,10 @@ def get_tokens(doc):
 
 def get_n_tokens(doc):
     """
-    Get the number of tokens (including punctuation) in ``doc``.
+    Get the number of tokens (including punctuation) in ``Doc``.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
 
     Returns:
         int
@@ -121,17 +136,23 @@ def get_n_tokens(doc):
 
 def get_n_sents(doc):
     """
-    Get the number of sentences in ``doc``.
+    Get the number of sentences in ``Doc``.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
 
     Returns:
         int
     """
-    return sum(1 for _ in doc.sents)
+    return itertoolz.count(doc.sents)
 
 
 def get_meta(doc):
     """
-    Get custom metadata added to ``doc``.
+    Get custom metadata added to ``Doc``.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
 
     Returns:
         dict
@@ -141,7 +162,7 @@ def get_meta(doc):
 
 def set_meta(doc, value):
     """
-    Add custom metadata to ``doc``.
+    Add custom metadata to ``Doc``.
 
     Args:
         doc (:class:`spacy.tokens.Doc`)
@@ -158,7 +179,10 @@ def set_meta(doc, value):
 
 def to_tokenized_text(doc):
     """
-    Transform ``doc`` into an ordered, nested list of token-texts per sentence.
+    Transform ``Doc`` into an ordered, nested list of token-texts per sentence.
+
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
 
     Returns:
         List[List[str]]
@@ -178,9 +202,12 @@ def to_tokenized_text(doc):
 
 def to_tagged_text(doc):
     """
-    Transform ``doc`` into an ordered, nested list of (token-text, part-of-speech tag)
+    Transform ``Doc`` into an ordered, nested list of (token-text, part-of-speech tag)
     pairs per sentence.
 
+    Args:
+        doc (:class:`spacy.tokens.Doc`)
+
     Returns:
         List[List[Tuple[str, str]]]
 
@@ -206,24 +233,33 @@ def to_terms_list(
     **kwargs
 ):
     """
-    Transform :class:`Doc` into a sequence of ngrams and/or named entities, which
-    aren't necessarily in order of appearance, where each term appears in
-    the list with the same frequency that it appears in :class:`Doc`.
+    Transform ``Doc`` into a sequence of ngrams and/or entities — not necessarily
+    in order of appearance — where each appears in the sequence as many times as
+    it appears in ``Doc``.
 
     Args:
-        ngrams (int or Set[int]): n of which n-grams to include; ``(1, 2, 3)``
-            (default) includes unigrams (words), bigrams, and trigrams; `2`
-            if only bigrams are wanted; falsy (e.g. False) to not include any
-        entities (bool): if True (default), include named entities
-            in the terms list; note: if ngrams are also included, named
-            entities are added *first*, and any ngrams that exactly overlap
-            with an entity are skipped to prevent double-counting
-        normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
-            lowercase terms; if false-y, use the form of terms as they appear
-            in doc; if a callable, must accept a ``spacy.Token`` or ``spacy.Span``
-            and return a str, e.g. :func:`textacy.spacier.utils.get_normalized_text()`
-        as_strings (bool): if True, terms are returned as strings; if False
-            (default), terms are returned as their unique integer ids
+        doc (:class:`spacy.tokens.Doc`)
+        ngrams (int or Set[int] or None): ngrams to include in the terms list.
+            If ``{1, 2, 3}``, unigrams, bigrams, and trigrams are included;
+            if ``2``, only bigrams are included; if None, ngrams aren't included,
+            except for those belonging to named entities.
+        entities (bool or None): If True, entities are included in the terms list;
+            if False, they are *excluded* from the list; if None, entities
+            aren't included or excluded at all.
+
+            .. note:: When both ``entities`` and ``ngrams`` are non-null,
+               exact duplicates (based on start and end indexes) are handled.
+               If ``entities`` is True, any duplicate entities are included
+               while duplicate ngrams are discarded to avoid double-counting;
+               if ``entities`` is False, no entities are included of course,
+               and duplicate ngrams are discarded as well.
+
+        normalize (str or callable): If "lemma", lemmatize terms; if "lower",
+            lowercase terms; if falsy, use the form of terms as they appear in doc;
+            if callable, must accept a ``Token`` or ``Span`` and return a str,
+            e.g. :func:`get_normalized_text() <textacy.spacier.utils.get_normalized_text>`.
+        as_strings (bool): If True, terms are returned as strings;
+            if False, terms are returned as their unique integer ids.
         kwargs:
             - filter_stops (bool)
             - filter_punct (bool)
@@ -235,125 +271,110 @@ def to_terms_list(
             - exclude_types (str or Set[str]
             - drop_determiners (bool)
 
-            see :func:`extract.words <textacy.extract.words>`,
-            :func:`extract.ngrams <textacy.extract.ngrams>`,
-            and :func:`extract.entities <textacy.extract.entities>`
-            for more information on these parameters
+            See :func:`textacy.extract.words()`, :func:`textacy.extract.ngrams()`,
+            and :func:`textacy.extract.entities()` for details.
 
     Yields:
         int or str: the next term in the terms list, either as a unique
         integer id or as a string
 
     Raises:
-        ValueError: if neither ``entities`` nor ``ngrams`` are included
+        ValueError: if neither ``entities`` nor ``ngrams`` are included,
+            or if ``entities`` or ``normalize`` have invalid values
 
     Note:
         Despite the name, this is a generator function; to get an
-        actual list of terms, call ``list(doc.to_terms_list())``.
+        actual list of terms, call ``list(to_terms_list(doc))``.
     """
     if not (entities or ngrams):
-        raise ValueError("either `entities` or `ngrams` must be included")
-    if ngrams and isinstance(ngrams, int):
-        ngrams = (ngrams,)
-    if entities is True:
-        ne_kwargs = {
-            "include_types": kwargs.get("include_types"),
-            "exclude_types": kwargs.get("exclude_types"),
-            "drop_determiners": kwargs.get("drop_determiners", True),
-            "min_freq": kwargs.get("min_freq", 1),
-        }
-        # if numeric ngrams are to be filtered, we should filter numeric entities
-        if ngrams and kwargs.get("filter_nums") is True:
-            if ne_kwargs["exclude_types"]:
-                if isinstance(
-                    ne_kwargs["exclude_types"], (set, frozenset, list, tuple)
-                ):
-                    ne_kwargs["exclude_types"] = set(ne_kwargs["exclude_types"])
-                    ne_kwargs["exclude_types"].add(constants.NUMERIC_ENT_TYPES)
-            else:
-                ne_kwargs["exclude_types"] = constants.NUMERIC_ENT_TYPES
-    if ngrams:
-        ngram_kwargs = {
-            "filter_stops": kwargs.get("filter_stops", True),
-            "filter_punct": kwargs.get("filter_punct", True),
-            "filter_nums": kwargs.get("filter_nums", False),
-            "include_pos": kwargs.get("include_pos"),
-            "exclude_pos": kwargs.get("exclude_pos"),
-            "min_freq": kwargs.get("min_freq", 1),
-        }
-        # if numeric entities are to be filtered, we should filter numeric ngrams
-        if (
-            entities
-            and ne_kwargs["exclude_types"]
-            and any(
-                ent_type in ne_kwargs["exclude_types"]
-                for ent_type in constants.NUMERIC_ENT_TYPES
+        raise ValueError("`entities` and/or `ngrams` must be included")
+    if not (entities is None or isinstance(entities, bool)):
+        raise ValueError(
+            "entities={} is invalid; choices are {}".format(
+                entities,
+                {True, False, None},
             )
-        ):
-            ngram_kwargs["filter_nums"] = True
-
-    terms = []
-    # special case: ensure that named entities aren't double-counted when
-    # adding words or ngrams that were already added as named entities
-    if entities is True and ngrams:
-        ents = tuple(extract.entities(doc, **ne_kwargs))
-        ent_idxs = {(ent.start, ent.end) for ent in ents}
-        terms.append(ents)
-        for n in ngrams:
+        )
+    if not (normalize in ("lemma", "lower") or callable(normalize) or not normalize):
+        raise ValueError(
+            "normalize={} is invalid; choices are {}".format(
+                normalize,
+                {"lemma", "lower", types.FunctionType, None},
+            )
+        )
+    if ngrams:
+        unigrams_ = []
+        ngrams_ = []
+        ng_kwargs = {
+            "filter_stops", "filter_punct", "filter_nums",
+            "include_pos", "exclude_pos",
+            "min_freq",
+        }
+        ng_kwargs = {key: val for key, val in kwargs.items() if key in ng_kwargs}
+        for n in sorted(utils.to_collection(ngrams, int, set)):
+            # use a faster function for unigrams
             if n == 1:
-                terms.append(
-                    (
-                        word
-                        for word in extract.words(doc, **ngram_kwargs)
-                        if (word.i, word.i + 1) not in ent_idxs
-                    )
-                )
+                unigrams_ = extract.words(doc, **ng_kwargs)
             else:
-                terms.append(
-                    (
-                        ngram
-                        for ngram in extract.ngrams(doc, n, **ngram_kwargs)
-                        if (ngram.start, ngram.end) not in ent_idxs
-                    )
-                )
-    # otherwise, no need to check for overlaps
-    else:
-        if entities is True:
-            terms.append(extract.entities(doc, **ne_kwargs))
+                ngrams_.append(extract.ngrams(doc, n, **ng_kwargs))
+        ngrams_ = itertoolz.concat(ngrams_)
+    if entities is not None:
+        ent_kwargs = {"include_types", "exclude_types", "drop_determiners", "min_freq"}
+        ent_kwargs = {key: val for key, val in kwargs.items() if key in ent_kwargs}
+        entities_ = extract.entities(doc, **ent_kwargs)
+    if ngrams:
+        # use ngrams as-is
+        if entities is None:
+            terms = itertoolz.concatv(unigrams_, ngrams_)
+        # remove unigrams + ngrams that are duplicates of entities
         else:
-            for n in ngrams:
-                if n == 1:
-                    terms.append(extract.words(doc, **ngram_kwargs))
-                else:
-                    terms.append(extract.ngrams(doc, n, **ngram_kwargs))
+            entities_ = tuple(entities_)
+            ent_idxs = {(ent.start, ent.end) for ent in entities_}
+            unigrams_ = (
+                ug
+                for ug in unigrams_
+                if (ug.i, ug.i + 1) not in ent_idxs
+            )
+            ngrams_ = (
+                ng
+                for ng in ngrams_
+                if (ng.start, ng.end) not in ent_idxs
+            )
+            # add unigrams and ngrams, only
+            if entities is False:
+                terms = itertoolz.concatv(unigrams_, ngrams_)
+            # add unigrams, ngrams, and entities
+            else:
+                terms = itertoolz.concatv(unigrams_, ngrams_, entities_)
+    # use entities as-is
+    else:
+        terms = entities_
 
-    terms = itertoolz.concat(terms)
-
-    # convert token and span objects into integer ids
+    # convert spans into integer ids
     if as_strings is False:
+        ss = doc.vocab.strings
         if normalize == "lemma":
             for term in terms:
                 try:
                     yield term.lemma
                 except AttributeError:
-                    yield doc.vocab.strings.add(term.lemma_)
+                    yield ss.add(term.lemma_)
         elif normalize == "lower":
             for term in terms:
                 try:
                     yield term.lower
                 except AttributeError:
-                    yield doc.vocab.strings.add(term.lower_)
-        elif not normalize:
+                    yield ss.add(term.lower_)
+        elif callable(normalize):
             for term in terms:
-                try:
-                    yield term.orth
-                except AttributeError:
-                    yield doc.vocab.strings.add(term.text)
+                yield ss.add(normalize(term))
         else:
             for term in terms:
-                yield doc.vocab.strings.add(normalize(term))
-
-    # convert token and span objects into strings
+                try:
+                    yield term.text
+                except AttributeError:
+                    yield ss.add(term.text)
+    # convert spans into strings
     else:
         if normalize == "lemma":
             for term in terms:
@@ -361,12 +382,12 @@ def to_terms_list(
         elif normalize == "lower":
             for term in terms:
                 yield term.lower_
-        elif not normalize:
-            for term in terms:
-                yield term.text
-        else:
+        elif callable(normalize):
             for term in terms:
                 yield normalize(term)
+        else:
+            for term in terms:
+                yield term.text
 
 
 def to_bag_of_terms(
@@ -379,28 +400,28 @@ def to_bag_of_terms(
     **kwargs
 ):
     """
-    Transform :class:`Doc` into a bag-of-terms: the set of unique terms in
-    :class:`Doc` mapped to their frequency of occurrence, where "terms"
-    includes ngrams and/or named entities.
+    Transform ``Doc`` into a bag-of-terms: the set of unique terms in ``Doc``
+    mapped to their frequency of occurrence, where "terms" includes ngrams and/or entities.
 
     Args:
+        doc (:class:`spacy.tokens.Doc`)
         ngrams (int or Set[int]): n of which n-grams to include; ``(1, 2, 3)``
             (default) includes unigrams (words), bigrams, and trigrams; `2`
             if only bigrams are wanted; falsy (e.g. False) to not include any
-        entities (bool): if True (default), include named entities;
+        entities (bool): If True (default), include named entities;
             note: if ngrams are also included, any ngrams that exactly
             overlap with an entity are skipped to prevent double-counting
-        normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
-            lowercase terms; if false-y, use the form of terms as they appear
-            in doc; if a callable, must accept a ``spacy.Token`` or ``spacy.Span``
-            and return a str, e.g. :func:`textacy.spacier.utils.get_normalized_text()`
-        weighting ({'count', 'freq', 'binary'}): Type of weight to assign to
-            terms. If 'count' (default), weights are the absolute number of
-            occurrences (count) of term in doc. If 'binary', all counts are
-            set equal to 1. If 'freq', term counts are normalized by the
+        normalize (str or callable): If "lemma", lemmatize terms; if "lower",
+            lowercase terms; if falsy, use the form of terms as they appear
+            in ``doc``; if a callable, must accept a ``Token`` or ``Span``
+            and return a str, e.g. :func:`textacy.spacier.utils.get_normalized_text()`.
+        weighting ({"count", "freq", "binary"}): Type of weight to assign to
+            terms. If "count" (default), weights are the absolute number of
+            occurrences (count) of term in doc. If "binary", all counts are
+            set equal to 1. If "freq", term counts are normalized by the
             total token count, giving their relative frequency of occurrence.
-        as_strings (bool): if True, words are returned as strings; if False
-            (default), words are returned as their unique integer ids
+        as_strings (bool): If True, words are returned as strings; if False
+            (default), words are returned as their unique integer ids.
         kwargs:
             - filter_stops (bool)
             - filter_punct (bool)
@@ -412,10 +433,8 @@ def to_bag_of_terms(
             - exclude_types (str or Set[str]
             - drop_determiners (bool)
 
-            See :func:`extract.words() <textacy.extract.words>`,
-            :func:`extract.ngrams() <textacy.extract.ngrams>`,
-            and :func:`extract.entities() <textacy.extract.entities>`
-            for more information on these parameters.
+            See :func:`textacy.extract.words()`, :func:`textacy.extract.ngrams()`,
+            and :func:`textacy.extract.entities()`  for details.
 
     Returns:
         dict: mapping of a unique term id or string (depending on the value
@@ -423,7 +442,7 @@ def to_bag_of_terms(
         of occurrence (depending on the value of ``weighting``).
 
     See Also:
-        :meth:`Doc.to_terms_list() <Doc.to_terms_list>`
+        :func:`to_terms_list()`, which is used under the hood.
     """
     if weighting not in {"count", "freq", "binary"}:
         raise ValueError('weighting "{}" is invalid'.format(weighting))
@@ -446,18 +465,18 @@ def to_bag_of_terms(
 
 def to_bag_of_words(doc, normalize="lemma", weighting="count", as_strings=False):
     """
-    Transform :class:`Doc` into a bag-of-words: the set of unique words in
-    :class:`Doc` mapped to their absolute, relative, or binary frequency of
-    occurrence.
+    Transform ``Doc`` into a bag-of-words: the set of unique words in ``Doc``
+    mapped to their absolute, relative, or binary frequency of occurrence.
 
     Args:
-        normalize (str): if 'lemma', lemmatize words before counting; if
-            'lower', lowercase words before counting; otherwise, words are
+        doc (:class:`spacy.tokens.Doc`)
+        normalize (str): If "lemma", lemmatize words before counting; if
+            "lower", lowercase words before counting; otherwise, words are
             counted using the form with which they they appear in doc
-        weighting ({'count', 'freq', 'binary'}): Type of weight to assign to
-            words. If 'count' (default), weights are the absolute number of
-            occurrences (count) of word in doc. If 'binary', all counts are
-            set equal to 1. If 'freq', word counts are normalized by the
+        weighting ({"count", "freq", "binary"}): Type of weight to assign to
+            words. If "count" (default), weights are the absolute number of
+            occurrences (count) of word in doc. If "binary", all counts are
+            set equal to 1. If "freq", word counts are normalized by the
             total token count, giving their relative frequency of occurrence.
             Note: The resulting set of frequencies won't (necessarily) sum
             to 1.0, since punctuation and stop words are filtered out after
@@ -477,28 +496,27 @@ def to_bag_of_words(doc, normalize="lemma", weighting="count", as_strings=False)
         else spacy.attrs.LOWER if normalize == "lower"
         else spacy.attrs.ORTH
     )
-    word_to_weight = doc.count_by(count_by)
+
+    wid_weights = doc.count_by(count_by)
     if weighting == "freq":
         n_tokens = len(doc)
-        word_to_weight = {
-            id_: weight / n_tokens for id_, weight in word_to_weight.items()
-        }
+        wid_weights = {wid: weight / n_tokens for wid, weight in wid_weights.items()}
     elif weighting == "binary":
-        word_to_weight = {word: 1 for word in word_to_weight.keys()}
+        wid_weights = {wid: 1 for wid in wid_weights.keys()}
 
     bow = {}
+    vocab = doc.vocab
     if as_strings is False:
-        for id_, weight in word_to_weight.items():
-            lexeme = doc.vocab[id_]
-            if lexeme.is_stop or lexeme.is_punct or lexeme.is_space:
-                continue
-            bow[id_] = weight
+        for wid, weight in wid_weights.items():
+            lex = vocab[wid]
+            if not (lex.is_stop or lex.is_punct or lex.is_space):
+                bow[wid] = weight
     else:
-        for id_, weight in word_to_weight.items():
-            lexeme = doc.vocab[id_]
-            if lexeme.is_stop or lexeme.is_punct or lexeme.is_space:
-                continue
-            bow[doc.vocab.strings[id_]] = weight
+        ss = doc.vocab.strings
+        for wid, weight in wid_weights.items():
+            lex = vocab[wid]
+            if not (lex.is_stop or lex.is_punct or lex.is_space):
+                bow[ss[wid]] = weight
     return bow
 
 
@@ -510,30 +528,31 @@ def to_semantic_network(
     window_width=10,
 ):
     """
-    Transform :class:`Doc` into a semantic network, where nodes are either
-    'words' or 'sents' and edges between nodes may be weighted in different ways.
+    Transform ``Doc`` into a semantic network, where nodes are either
+    "words" or "sents" and edges between nodes may be weighted in different ways.
 
     Args:
-        nodes ({'words', 'sents'}): type of doc component to use as nodes
-            in the semantic network
-        normalize (str or callable): if 'lemma', lemmatize terms; if 'lower',
-            lowercase terms; if false-y, use the form of terms as they appear
-            in doc; if a callable, must accept a ``spacy.Token`` or ``spacy.Span``
-            (if ``nodes`` = 'words' or 'sents', respectively) and return a
-            str, e.g. :func:`textacy.spacier.utils.get_normalized_text()`
-        edge_weighting (str): type of weighting to apply to edges
-            between nodes; if ``nodes == 'words'``, options are {'cooc_freq', 'binary'},
-            if ``nodes == 'sents'``, options are {'cosine', 'jaccard'}; if
-            'default', 'cooc_freq' or 'cosine' will be automatically used
-        window_width (int): size of sliding window over terms that
-            determines which are said to co-occur; only applicable if 'words'
+        doc (:class:`spacy.tokens.Doc`)
+        nodes ({"words", "sents"}): Type of doc component to use as nodes
+            in the semantic network.
+        normalize (str or callable): If "lemma", lemmatize terms; if "lower",
+            lowercase terms; if falsy, use the form of terms as they appear
+            in doc; if a callable, must accept a ``Token`` or ``Span``
+            (if ``nodes`` = "words" or "sents", respectively) and return a str,
+            e.g. :func:`get_normalized_text() <textacy.spacier.utils.get_normalized_text>`
+        edge_weighting (str): Type of weighting to apply to edges between nodes;
+            if ``nodes`` = "words", options are {"cooc_freq", "binary"},
+            if ``nodes`` = "sents", options are {"cosine", "jaccard"}; if
+            "default", "cooc_freq" or "cosine" will be automatically used.
+        window_width (int): Size of sliding window over terms that determines
+            which are said to co-occur; only applicable if ``nodes`` = "words".
 
     Returns:
         ``networkx.Graph``: where nodes represent either terms or sentences
         in doc; edges, the relationships between them.
 
     Raises:
-        ValueError: if ``nodes`` is neither 'words' nor 'sents'.
+        ValueError: If ``nodes`` is neither "words" nor "sents".
 
     See Also:
         - :func:`terms_to_semantic_network() <textacy.network.terms_to_semantic_network>`
