@@ -75,3 +75,34 @@ def is_record(obj):
         return True
     else:
         return False
+
+
+def to_collection(val, val_type, col_type):
+    """
+    Validate and cast a value or values to a collection.
+
+    Args:
+        val (object): Value or values to validate and cast.
+        val_type (type): Type of each value in collection, e.g. ``int`` or ``str``.
+        col_type (type): Type of collection to return, e.g. ``tuple`` or ``set``.
+
+    Returns:
+        object: Collection of type ``col_type`` with values all of type ``val_type``.
+
+    Raises:
+        TypeError
+    """
+    if val is None:
+        return None
+    if isinstance(val, val_type):
+        return col_type([val])
+    elif isinstance(val, (tuple, list, set, frozenset)):
+        if not all(isinstance(v, val_type) for v in val):
+            raise TypeError("not all values are of type {}".format(val_type))
+        return col_type(val)
+    else:
+        raise TypeError(
+            "values must be {} or a collection thereof, not {}".format(
+                val_type, type(val),
+            )
+        )
