@@ -4,6 +4,9 @@ import textacy
 print("import: 'textacy.cache'")
 import textacy.cache
 
+print("import: 'textacy.compat'")
+import textacy.compat
+
 print("import: 'textacy.constants'")
 import textacy.constants
 
@@ -28,12 +31,12 @@ import textacy.io
 print("import: 'textacy.keyterms'")
 import textacy.keyterms
 
+print("import: 'textacy.lang_utils'")
+import textacy.lang_utils
+
 print("import: 'textacy.lexicon_methods'")
 import textacy.lexicon_methods
 
-print("import: 'textacy.math_utils'")
-import textacy.math_utils
-
 print("import: 'textacy.network'")
 import textacy.network
 
@@ -46,12 +49,6 @@ import textacy.similarity
 print("import: 'textacy.spacier'")
 import textacy.spacier
 
-print("import: 'textacy.spacy_pipelines'")
-import textacy.spacy_pipelines
-
-print("import: 'textacy.spacy_utils'")
-import textacy.spacy_utils
-
 print("import: 'textacy.text_stats'")
 import textacy.text_stats
 
